@@ -1,14 +1,8 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import re
 from uuid import uuid4
 
 from .common import InfoExtractor
-from ..compat import (
-    compat_HTTPError,
-    compat_str,
-)
+from ..compat import compat_HTTPError, compat_str
 from ..utils import (
     ExtractorError,
     int_or_none,
@@ -223,7 +217,7 @@ class ZattooPlatformBaseIE(InfoExtractor):
             'id': channel_name,
             'title': channel_name,
             'is_live': True,
-            'format': formats,
+            'formats': formats,
             'subtitles': subtitles
         }
 
@@ -240,6 +234,10 @@ class ZattooPlatformBaseIE(InfoExtractor):
             ondemand_termtoken=ondemand_termtoken, ondemand_type=ondemand_type)
         return info_dict
 
+    def _real_extract(self, url):
+        video_id, record_id = self._match_valid_url(url).groups()
+        return self._extract_video(video_id, record_id)
+
 
 def _make_valid_url(host):
     return rf'https?://(?:www\.)?{re.escape(host)}/watch/[^/]+?/(?P<id>[0-9]+)[^/]+(?:/(?P<recid>[0-9]+))?'
